@@ -1,4 +1,4 @@
-"""Inspect photos selected in Photos """
+"""Inspect photos selected in Photos"""
 
 from __future__ import annotations
 
@@ -413,7 +413,7 @@ def get_photo_type(photo: PhotoInfo) -> str:
     if photo.screenshot:
         photo_type += " screenshot"
     if photo.screen_recording:
-        photo_type += " screen recording"        
+        photo_type += " screen recording"
     if photo.slow_mo:
         photo_type += " slow-mo"
     if photo.time_lapse:
@@ -492,7 +492,7 @@ def make_layout() -> Layout:
 def photo_inspect(db, theme, detect_text, template, beta):
     """Interactively inspect photos selected in Photos.
 
-    Open Photos then run `osxphotos inspect` in the terminal.
+    Open Photos then run 'osxphotos inspect' in the terminal.
     As you select a photo in Photos, inspect will display metadata about the photo.
     Press Ctrl+C to exit when done.
     Works best with a modern terminal like iTerm2 or Kitty.
